@@ -276,6 +276,8 @@ class PPIMBC(TransformerMixin, BaseEstimator):
 
         sns.barplot(x=x_axis, y=y_axis, orient="h")
         plt.yticks(y_axis, [str(i) for i in self.MB], size='small')
+        plt.xlabel("Importance Scores")
+        plt.ylabel("Features")
         sns.despine()
         plt.show()
         
@@ -542,5 +544,7 @@ class PPIMBR(TransformerMixin, BaseEstimator):
 
         sns.barplot(x=x_axis, y=y_axis, orient="h")
         plt.yticks(y_axis, [str(i) for i in self.MB], size='small')
+        plt.xlabel("Importance Scores")
+        plt.ylabel("Features")
         sns.despine()
         plt.show()
